@@ -71,7 +71,7 @@ static int mock_http_server(BIO *in, BIO *out, char version, int keep_alive,
     hdr = strchr(hdr, ' ');
     if (hdr == NULL)
         return 0;
-    len = strlen("HTTP/1.");
+    len = (int)strlen("HTTP/1.");
     if (!TEST_strn_eq(++hdr, "HTTP/1.", len))
         return 0;
     hdr += len;
@@ -81,7 +81,7 @@ static int mock_http_server(BIO *in, BIO *out, char version, int keep_alive,
     if (!TEST_char_eq(*hdr++, '\r') || !TEST_char_eq(*hdr++, '\n'))
         return 0;
 
-    count -= (hdr - req);
+    count -= (long)(hdr - req);
     if (count < 0 || out == NULL)
         return 0;
 
@@ -107,7 +107,7 @@ static int mock_http_server(BIO *in, BIO *out, char version, int keep_alive,
 
     if (is_get) { /* construct new header and body */
         if (txt != NULL)
-            len = strlen(txt);
+            len = (int)strlen(txt);
         else if ((len = ASN1_item_i2d(rsp, NULL, it)) <= 0)
             return 0;
         if (BIO_printf(out, "Content-Type: %s\r\n"
@@ -332,6 +332,16 @@ static int test_http_url_dns(void)
     return test_http_url_ok("host:65535/path", 0, "host", "65535", "/path");
 }
 
+static int test_http_url_timestamp(void)
+{
+    return test_http_url_ok("host/p/2017-01-03T00:00:00", 0, "host", "80",
+                            "/p/2017-01-03T00:00:00")
+        && test_http_url_ok("http://host/p/2017-01-03T00:00:00", 0, "host",
+                            "80", "/p/2017-01-03T00:00:00")
+        && test_http_url_ok("https://host/p/2017-01-03T00:00:00", 1, "host",
+                            "443", "/p/2017-01-03T00:00:00");
+}
+
 static int test_http_url_path_query(void)
 {
     return test_http_url_path_query_ok("http://usr@host:1/p?q=x#frag", "/p?q=x")
@@ -559,6 +569,7 @@ int setup_tests(void)
         return 0;
 
     ADD_TEST(test_http_url_dns);
+    ADD_TEST(test_http_url_timestamp);
     ADD_TEST(test_http_url_path_query);
     ADD_TEST(test_http_url_userinfo_query_fragment);
     ADD_TEST(test_http_url_ipv4);
